from .tournamentsresource import TournamentsResource

ROOT_PATH = "https://api.challonge.com/v1"


class ChallongeService():

    def __init__(self, api_key: str):
        self._tournaments = TournamentsResource(api_key, ROOT_PATH)

    def tournaments(self):
        return self._tournaments


def create_service(api_key: str) -> ChallongeService:
    return ChallongeService(api_key)


from .api import get


class TournamentsResource():

    def __init__(self, api_key: str, root_path: str):
        self._api_key = api_key
        self._base_path = root_path + "/tournaments"

    def index(self, **kwargs):
        return get(self._api_key, self._base_path + ".json", **kwargs)



import http.client
import urllib.request
import urllib.parse
import json


class ApiError(Exception):

    def __init__(self, message):
        self.message = message


def _check_for_errors(response: http.client.HTTPResponse):
    content_type = response.getheader("Content-Type", "")

    if "application/json" not in content_type:
        raise ApiError("Did not receive JSON response when opening path:\n" + response.geturl())


def get(api_key: str, path: str, **kwargs) -> dict:
    kwargs["api_key"] = api_key
    response = urllib.request.urlopen(path + "?" + urllib.parse.urlencode(kwargs))
    _check_for_errors(response)

    content_charset = response.info().get_content_charset("utf-8")
    return json.loads(response.read().decode(content_charset))




from distutils.core import setup
setup(
  name='challonge-service',
  packages=['challongeservice'],
  version='0.0.1',
  description='Python binding for Challonge v1 API',
  author='Hugo Wainwright',
  author_email='wainwrighthugo@gmail.com',
  url='https://github.com/frugs/challonge-service',
  download_url='https://github.com/frugs/challonge-service/tarball/0.0.1',
  keywords=['challonge'],
  classifiers=[],
)
